// 节流
import config from '@/config';
export const throttle = (func, wait = 500, immediate = true) => {
	// eslint-disable-next-line no-unused-vars
	let flag, timer;
	if (immediate) {
		if (!flag) {
			flag = true;
			// 如果是立即执行，则在wait毫秒内开始时执行
			typeof func === 'function' && func();
			timer = setTimeout(() => {
				flag = false;
			}, wait);
		}
	} else {
		if (!flag) {
			flag = true;
			// 如果是非立即执行，则在wait毫秒内的结束处执行
			timer = setTimeout(() => {
				flag = false;
				typeof func === 'function' && func();
			}, wait);
		}
	}
};

// 防抖
let timeout = null;
/**
 * 防抖原理：一定时间内，只有最后一次操作，再过wait毫秒后才执行函数
 *
 * @param {Function} func 要执行的回调函数
 * @param {Number} wait 延时的时间
 * @param {Boolean} immediate 是否立即执行
 * @return null
 */
export const debounce = (func, wait = 500, immediate = false) => {
	// 清除定时器
	if (timeout !== null) clearTimeout(timeout);
	// 立即执行，此类情况一般用不到
	if (immediate) {
		var callNow = !timeout;
		timeout = setTimeout(function () {
			timeout = null;
		}, wait);
		if (callNow) typeof func === 'function' && func();
	} else {
		// 设置定时器，当最后一次操作后，timeout不会再被清除，所以在延时wait毫秒后执行func回调方法
		timeout = setTimeout(function () {
			typeof func === 'function' && func();
		}, wait);
	}
};

// 控制台打印
const log = {};
/**
 * @description 返回这个样式的颜色值
 * @param {String} type 样式名称 [ primary | success | warning | danger | text ]
 */
 function typeColor(type = 'default') {
  const colors = {
    default: '#35495E',
    primary: '#3488ff',
    success: '#43B883',
    warning: '#e6a23c',
    danger: '#f56c6c'
  };
  return colors[type] || '';
}
/**
 * @description 打印一个 [ title | text ] 样式的信息
 * @param {String} title title text
 * @param {String} info info text
 * @param {String} type style
 */
log.capsule = function (title, info, type = 'primary') {
	console.log(
		`%c ${title} %c ${info} %c`,
		'background:#35495E; padding: 1px; border-radius: 3px 0 0 3px; color: #fff;',
		`background:${typeColor(type)}; padding: 1px; border-radius: 0 3px 3px 0;  color: #fff;`,
		'background:transparent'
	);
};
/**
 * @description 打印彩色文字
 */
log.colorful = function (textArr) {
	console.log(
		`%c${textArr.map((t) => t.text || '').join('%c')}`,
		...textArr.map((t) => `color: ${typeColor(t.type)};`)
	);
};
/**
 * @description 打印 default 样式的文字
 */
log.default = function (text) {
	log.colorful([{ text }]);
};
/**
 * @description 打印 primary 样式的文字
 */
log.primary = function (text) {
	log.colorful([{ text, type: 'primary' }]);
};
/**
 * @description 打印 success 样式的文字
 */
log.success = function (text) {
	log.colorful([{ text, type: 'success' }]);
};
/**
 * @description 打印 warning 样式的文字
 */
log.warning = function (text) {
	log.colorful([{ text, type: 'warning' }]);
};
/**
 * @description 打印 danger 样式的文字
 */
log.danger = function (text) {
	log.colorful([{ text, type: 'danger' }]);
};
export const Log = log;

// 数据
// 判断arr是否为一个数组，返回一个bool值
const isArray = (arr) => Object.prototype.toString.call(arr) === '[object Array]';
// 深度克隆
export const deepClone = (obj) => {
	if ([null, undefined, NaN, false].includes(obj)) return obj;
	if (typeof obj !== 'object' && typeof obj !== 'function') return obj;
	const o = isArray(obj) ? [] : {};
	for (const i in obj) {
		if (Object.hasOwnProperty.call(obj, i)) {
			o[i] = typeof obj[i] === 'object' ? deepClone(obj[i]) : obj[i];
		}
	}
	return o;
};

// 返回随机数
export const random = (min = 0, max = 100) => {
	if (min >= 0 && max > 0 && max >= min) {
		const gab = max - min + 1;
		return Math.floor(Math.random() * gab + min);
	} else {
		return 0;
	}
};
// 数组打乱顺序
export const randomArray = (array = []) => {
	// 原理是sort排序,Math.random()产生0<= x < 1之间的数,会导致x-0.05大于或者小于0
	return array.sort(() => Math.random() - 0.5);
};

// 判断是否为空
export const isEmpty = (value) => {
	switch (typeof value) {
		case 'undefined':
			return true;
		case 'string':
			if (value.replace(/(^[ \t\n\r]*)|([ \t\n\r]*$)/g, '').length === 0) {
				return true;
			}
			break;
		case 'boolean':
			if (!value) return true;
			break;
		case 'number':
			if (value === 0 || isNaN(value)) return true;
			break;
		case 'object':
			if (value === null || value.length === 0) return true;
			for (var i in value) {
				return false;
			}
			return true;
	}
	return false;
};
// 去空格
export const trim = (str, pos = 'both') => {
	if (pos === 'both') {
		return str.replace(/^\s+|\s+$/g, '');
	} else if (pos === 'left') {
		return str.replace(/^\s*/, '');
	} else if (pos === 'right') {
		return str.replace(/(\s*$)/g, '');
	} else if (pos === 'all') {
		return str.replace(/\s+/g, '');
	} else {
		return str;
	}
};

// 返回当前数据类型  String   Number Boolean Function Array Object Date RegExp Math Undefined Null
export const getDataType = (value) => {
	return Object.prototype.toString.call(value).slice(8, -1);
};
// 返回url参数
export const getQueryVariable = (variable) => {
	const query = window.location.search.substring(1);
	const vars = query.split('&');
	for (var i = 0; i < vars.length; i++) {
		var pair = vars[i].split('=');
		// eslint-disable-next-line eqeqeq
		if (pair[0] == variable) return pair[1];
	}
	return false;
};
// 数字格式化
export const formatNumber = (number = 0, places = 2, thousand = '', symbol = '', decimal = '.') => {const noSetArr = ['',undefined,null];
  if(noSetArr.includes(number)){
    return ''
  }
	const negative = number < 0 ? '-' : '';
	const i = parseInt((number = Math.abs(+number || 0).toFixed(places)), 10) + '';
	// eslint-disable-next-line no-use-before-define
	let j = (j = i.length) > 3 ? j % 3 : 0;
	return (
		symbol +
		negative +
		(j ? i.substr(0, j) + thousand : '') +
		i.substr(j).replace(/(\d{3})(?=\d)/g, '$1' + thousand) +
		(places
			? decimal +
			  Math.abs(number - i)
					.toFixed(places)
					.slice(2)
			: '')
	);
};
// 数字反格式化
export const eFormatNumber = (number = 0, thousand = ',') => {
	if (getDataType(number) === 'Number') {
		return number;
	}
	return Number(number.replace(/,/gi, ''));
};

// 数组对象排序  [{a:'asas',b:2},{a:'as',b:0}].sort(createComparator('b'))
export const createComparator = (property) => {
	return (object1, object2) => {
		const value1 = Number(object1[property]);
		const value2 = Number(object2[property]);
		if (value1 < value2) {
			return -1;
		} else if (value1 > value2) {
			return 1;
		} else {
			return 0;
		}
	};
};

// 时间
// 时间日期格式化 y - 年 M -月 d- 日 h - 时 m - 分 s - 秒
// yyyy:MM:dd|yyyy:MM|yyyy年MM月dd日|yyyy年MM月dd日 hh时mm分等,可自定义组合
export const timeFormat = (timestamp = null, fmt = 'yyyy-MM-dd hh:mm:ss') => {
	timestamp = parseInt(timestamp);
	// 如果为null,则格式化当前时间
	if (!timestamp) timestamp = Number(new Date());
	// 判断用户输入的时间戳是秒还是毫秒,一般前端js获取的时间戳是毫秒(13位),后端传过来的为秒(10位)
	if (timestamp.toString().length === 10) timestamp *= 1000;
	const date = new Date(timestamp);
	let ret;
	const opt = {
		'y+': date.getFullYear().toString(), // 年
		'M+': (date.getMonth() + 1).toString(), // 月
		'd+': date.getDate().toString(), // 日
		'h+': date.getHours().toString(), // 时
		'm+': date.getMinutes().toString(), // 分
		's+': date.getSeconds().toString() // 秒
	};
	for (const k in opt) {
		ret = new RegExp('(' + k + ')').exec(fmt);
		if (ret) {
			fmt = fmt.replace(ret[1], ret[1].length === 1 ? opt[k] : opt[k].padStart(ret[1].length, '0'));
		}
	}
	return fmt;
};
/**
 * 日期格式化
 * @param Number time 时间戳
 * @param String format 格式
 */
export const dateFormat = (time, format) => {
	const t = new Date(time);
	// 日期格式
	format = format || 'Y-m-d h:i:s';
	const year = t.getFullYear();
	// 由于 getMonth 返回值会比正常月份小 1
	const month = t.getMonth() + 1;
	const day = t.getDate();
	const hours = t.getHours();
	const minutes = t.getMinutes();
	const seconds = t.getSeconds();

	const hash = {
		y: year,
		m: month,
		d: day,
		h: hours,
		i: minutes,
		s: seconds
	};
	// 是否补 0
	const isAddZero = (o) => {
		return /M|D|H|I|S/.test(o);
	};
	return format.replace(/\w/g, (o) => {
		const rt = hash[o.toLocaleLowerCase()];
		return rt >= 10 || !isAddZero(o) ? rt : `0${rt}`;
	});
};
// 时间格式化
export const tformat = function (date, format) {
	date = new Date(date);
	const o = {
		'M+': date.getMonth() + 1,
		'd+': date.getDate(),
		'H+': date.getHours(),
		'm+': date.getMinutes(),
		's+': date.getSeconds(),
		'q+': Math.floor((date.getMonth() + 3) / 3), // 季度
		'f+': date.getMilliseconds() // 毫秒
	};
	if (/(y+)/.test(format)) {
		format = format.replace(RegExp.$1, date.getFullYear() + '').substr(4 - RegExp.$1.length);
	}
	for (const k in o) {
		if (new RegExp('(' + k + ')').test(format)) {
			format = format.replace(
				RegExp.$1,
				RegExp.$1.length === 1 ? o[k] : ('00' + o[k]).substr(('' + o[k]).length)
			);
		}
	}
	return format;
};
// 时间戳转 多久之前
export const timeFrom = (timestamp = null, format = 'yyyy-MM-dd') => {
	if (timestamp == null) timestamp = Number(new Date());
	timestamp = parseInt(timestamp);
	// 判断用户输入的时间戳是秒还是毫秒,一般前端js获取的时间戳是毫秒(13位),后端传过来的为秒(10位)
	if (timestamp.toString().length === 10) timestamp *= 1000;
	var timer = new Date().getTime() - timestamp;
	timer = parseInt(timer / 1000);
	// 如果小于5分钟,则返回"刚刚",其他以此类推
	let tips = '';
	switch (true) {
		case timer < 300:
			tips = '刚刚';
			break;
		case timer >= 300 && timer < 3600:
			tips = parseInt(timer / 60) + '分钟前';
			break;
		case timer >= 3600 && timer < 86400:
			tips = parseInt(timer / 3600) + '小时前';
			break;
		case timer >= 86400 && timer < 2592000:
			tips = parseInt(timer / 86400) + '天前';
			break;
		default:
			// 如果format为false，则无论什么时间戳，都显示xx之前
			if (format === false) {
				if (timer >= 2592000 && timer < 365 * 86400) {
					tips = parseInt(timer / (86400 * 30)) + '个月前';
				} else {
					tips = parseInt(timer / (86400 * 365)) + '年前';
				}
			} else {
				tips = timeFormat(timestamp, format);
			}
	}
	return tips;
};
// 秒格式化
export const secondToDate = (msd) => {
	var time = msd;
	if (time != null && time !== '') {
		if (time > 60 && time < 60 * 60) {
			time =
				parseInt(time / 60.0) +
				'分' +
				parseInt((parseFloat(time / 60.0) - parseInt(time / 60.0)) * 60) +
				'秒';
		} else if (time >= 60 * 60 && time < 60 * 60 * 24) {
			time =
				parseInt(time / 3600.0) +
				'时' +
				parseInt((parseFloat(time / 3600.0) - parseInt(time / 3600.0)) * 60) +
				'分' +
				parseInt(
					(parseFloat((parseFloat(time / 3600.0) - parseInt(time / 3600.0)) * 60) -
						parseInt((parseFloat(time / 3600.0) - parseInt(time / 3600.0)) * 60)) *
						60
				) +
				'秒';
		} else if (time >= 60 * 60 * 24) {
			time =
				parseInt(time / 3600.0 / 24) +
				'天' +
				parseInt((parseFloat(time / 3600.0 / 24) - parseInt(time / 3600.0 / 24)) * 24) +
				'时' +
				parseInt((parseFloat(time / 3600.0) - parseInt(time / 3600.0)) * 60) +
				'分' +
				parseInt(
					(parseFloat((parseFloat(time / 3600.0) - parseInt(time / 3600.0)) * 60) -
						parseInt((parseFloat(time / 3600.0) - parseInt(time / 3600.0)) * 60)) *
						60
				) +
				'秒';
		} else {
			time = parseInt(time) + '秒';
		}
	}
	return time;
};
// 返回当前日期的前 n 天的时间戳 默认前 30天
export const getPrevTimer = (n = 30) => {
	const nowTime = new Date().getTime();
	const prevTime = 1000 * 60 * 60 * 24 * n;
	return nowTime - prevTime;
};
export const getTimeFormat = (time) => {
	if (time === undefined) {
		return;
	}
	if (time.length === 14) {
		time =
			time.slice(0, 4) +
			'/' +
			time.slice(4, 6) +
			'/' +
			time.slice(6, 8) +
			' ' +
			time.slice(8, 10) +
			':' +
			time.slice(10, 12) +
			':' +
			time.slice(12, 14);
	} else if (time.length === 8) {
		time = time.slice(0, 4) + '/' + time.slice(4, 6) + '/' + time.slice(6, 8);
	} else if (time.length === 6) {
		time = time.slice(0, 4) + '/' + time.slice(4, 6);
	}
	return time;
};
// 字符串复制到粘贴板
export const execCommand = (str) => {
	return new Promise((resolve, reject) => {
		const body = document.getElementsByTagName('body')[0];
		const input = document.createElement('input');
		input.value = str;
		input.disabled = false;
		body.appendChild(input);
		input.select();
		try {
			if (document.execCommand('Copy', 'false', null)) {
				resolve(true);
			} else {
				resolve(false);
			}
		} catch (err) {
			resolve(false);
		}
		body.removeChild(input);
	});
};
// 数组去重 单个参数去重  两个 合并数组去重 返回新数组
export const distinct = (a, b) => {
	const arr = a.concat(b);
	const result = [];
	const obj = {};
	for (const i of arr) {
		if (!obj[i]) {
			result.push(i);
			obj[i] = 1;
		}
	}
	return result;
};

// 更新网站标题
export const changeTitle = (titleText) => {
	// const processTitle = config.title;
	// window.document.title = `${processTitle}${titleText ? ` | ${titleText}` : ''}`;
	window.document.title = `${titleText}`;
};

// 判断当前环境
export const browserRedirect = () => {
	let result = '';
	const sUserAgent = navigator.userAgent.toLowerCase();
	const bIsIpad = sUserAgent.match(/ipad/i) === 'ipad';
	const bIsIphoneOs = sUserAgent.match(/iphone os/i) === 'iphone os';
	const bIsMidp = sUserAgent.match(/midp/i) === 'midp';
	const bIsUc7 = sUserAgent.match(/rv:1.2.3.4/i) === 'rv:1.2.3.4';
	const bIsUc = sUserAgent.match(/ucweb/i) === 'ucweb';
	const bIsAndroid = sUserAgent.match(/android/i) === 'android';
	const bIsCE = sUserAgent.match(/windows ce/i) === 'windows ce';
	const bIsWM = sUserAgent.match(/windows mobile/i) === 'windows mobile';
	const weixin = sUserAgent.match(/micromessenger/i) === 'micromessenger';
	if (weixin) {
		result = 'weixin';
	} else if (bIsIpad || bIsIphoneOs || bIsMidp || bIsUc7 || bIsUc || bIsAndroid || bIsCE || bIsWM) {
		result = 'phone';
	} else {
		result = 'pc';
	}
	return result;
};

// 生成下载 pdf
export const handleWindowPrint = (ele, fileName, vm) => {
	var oIframe = document.createElement('iframe');
	var oScript = document.createElement('script');

	document.body.appendChild(oIframe);

	var titleText = document.head.getElementsByTagName('title')[0].innerText;
	document.head.getElementsByTagName('title')[0].innerText = `${fileName}`;

	oIframe.contentDocument.head.innerHTML = `<meta charset="utf-8">
                                            <title>${fileName}</title>
                                            <meta name="format-detection" content="telephone=no">
                                            <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
                                            <meta name="viewport" content="width=device-width,initial-scale=1.0">`;

	// oIframe.contentWindow.document.body.innerHTML = document.querySelector(ele).outerHTML;
	oIframe.contentDocument.body.innerHTML = ele.outerHTML;
	oScript.innerHTML = 'window.print();';
	oIframe.contentDocument.body.appendChild(oScript);
	document.body.removeChild(oIframe);
	document.head.getElementsByTagName('title')[0].innerText = titleText;
};

export const stringToByte = (value) => {
	const exp = '(^[0-9\\.]+)(\\w+)';
	const result = value.match(exp);

	if (!result) {
		return 0;
	}

	const size = result[1];
	const suffix = result[2].toLocaleUpperCase();

	const a = { B: 0, KB: 1, MB: 2, GB: 3, TB: 4, PB: 5 };
	const b = { B: 0, K: 1, M: 2, G: 3, T: 4, P: 5 };

	const pos =
		Object.prototype.hasOwnProperty.call(a, suffix) && a[suffix] !== 0 ? a[suffix] : b[suffix];
	return Math.round(size * Math.pow(1024, pos));
};

// 格式化select 数据
export const setSelectData = (data, label, value) =>
	data.map((e) => ({ value: e[value], label: e[label] }));

export const setSelectDatas = (data, label, value, children) => {
  let item=[];
  data.map(e=>{
      let newData={};
      newData.label=e[label];
      newData.value=e[value];
      if(e[children]){
          newData.children=setSelectDatas(e[children], label, value, children )
      }
      item.push(newData);
  })
  return item;
};
// export const getSelectLabels = (data, selectData) => {
//   let selectDatas = {};
//   for (let index = 0; index < data.length; index++) {
//     const e = data[index];
//     if(e.children){
//       getSelectLabels(e.children, selectData);
//     } else if(e === selectData){
//       selectDatas = e;
//       break;
//     }
//   }
//   return selectDatas;
// };

// 正则表达式
// 身份证号
export const regexpCard = /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/;
// 手机号
export const regexpPhone =
	/^(13[0-9]|14[01456879]|15[0-35-9]|16[2567]|17[0-8]|18[0-9]|19[0-35-9])\d{8}$/;
// 手机号
export const easyRegexpPhone = /^(1)\d{10}$/;

export const isJsonString = (str) => {
	try {
		if (typeof JSON.parse(str) === 'object') {
			return true;
		}
	} catch (e) {}
	return false;
};

// 数值千分位格式化
export const format = (num) => {
	if (isNaN(num)) {
		throw new TypeError('num is not a number');
	}

	// eslint-disable-next-line no-useless-escape
	var groups = /([\-\+]?)(\d*)(\.\d+)?/g.exec('' + num);
	var mask = groups[1]; // 符号位
	var integers = (groups[2] || '').split(''); // 整数部分
	var decimal = groups[3] || ''; // 小数部分
	var remain = integers.length % 3;

	var temp = integers
		.reduce(function (previousValue, currentValue, index) {
			if (index + 1 === remain || (index + 1 - remain) % 3 === 0) {
				return previousValue + currentValue + ',';
			} else {
				return previousValue + currentValue;
			}
		}, '')
		// eslint-disable-next-line no-useless-escape
		.replace(/\,$/g, '');
	return mask + temp + decimal;
};

/**
 * 格式化金额
 * @param  {[type]} v     [要转换的数字]
 * @param  {[type]} len   [小数点位数,默认2位]
 * @param  {[type]} split [分隔符,默认',']
 * @return {[type]}       [返回转换完的字符串]
 */
export const fmoney = (v, len, split) => {
	// eslint-disable-next-line no-sequences
	split = split || ',';
	len = Math.abs(+len % 20 || 2);
	// eslint-disable-next-line no-useless-escape
	v = parseFloat((v + '').replace(/[^\d\.-]/g, '')).toFixed(len) + '';
	return v.replace(/\d+/, function (v) {
		var lit = v.length % 3 === 0;
		var index = lit ? v.length - 3 : -1;
		return v
			.split('')
			.reverse()
			.join('')
			.replace(/\d{3}/g, function (k, l) {
				return k + (l === index && lit ? '' : split);
			})
			.split('')
			.reverse()
			.join('');
	});
};

export const money = (text) => {
	return text.toLocaleString('en-US');
};

// input输入框禁止输入负数
export const proving = (e) => {
	var keynum = window.event ? e.keyCode : e.which;
	// var keychar = String.fromCharCode(keynum);
	if (keynum === 189 || keynum === 109) {
		e.target.value = 1;
	}
};
// input输入框只能输入数字
export const filterInputNum = (e) => {
	var check = /(^[1-9]{1}[0-9]*$)|(^[0-9]*\.[0-9]{0,2}$)/;
	var value = e.target.value;
	if (!check.test(value)) {
		e.target.value = 0;
	}
};

export function arrToTree(array, id_key, parentId_key, isRoot) {
	if (!!!array) return tree;
	let idsObj = {},
		tree = [];
	array.forEach((item) => (idsObj[item[id_key]] = item));
	Object.values(idsObj).forEach((item) => {
		// console.log(item[parentId_key])
		let parentId = item[parentId_key],
			parent = idsObj[parentId];
		if (!isRoot(item, parent)) {
			!!!parent.children && (parent.children = []);
			let children = parent.children;
			!children.includes(item) && children.push(item);
		} else {
			tree.push(item);
		}
	});
	return tree;
}
export function listToTree(list) {
	list.forEach((element) => {
		const UP_SYS_CODE = element.UP_SYS_CODE;
		if (UP_SYS_CODE.length !== 3) {
			list.forEach((ele) => {
				if (ele.SYS_CODE === UP_SYS_CODE) {
					// 当内层循环的ID== 外层循环的parendId时，（说明有children），需要往该内层id里建个children并push对应的数组；
					if (!ele.children) {
						ele.children = [];
					}
					ele.children.push(element);
				}
			});
		}
	});
	list = list.filter((ele) => ele.UP_SYS_CODE.length === 3);
	return list;
}
export function isBoolean(value) {
	return typeof value === 'boolean';
}

export function throttles(fn, delay) {
	let prev = Date.now();
	return function () {
		let args = arguments;
		let context = this;
		let now = Date.now();

		if (now - prev > delay) {
			fn.apply(context, args);
			prev = Date.now();
		}
	};
}

// 预览图片地址
export const previewUrl = (id) => `/nh-cloud/img/${id}`;

export function validForbid(value, type = 'base', number = 255) {
	let reg = null;
	switch (type) {
		case 'base':
			reg = / /g;
			break;
		case 'special':
			reg =
				/[`~!@#$%^&*()_\-+=<>?:"{}|,./;'\\[\]·~！@#￥%……&*（）——\-+={}|《》？：“”【】、；‘’，。、a-zA-ZeE]/g;
			break;
		case 'special2':
			reg =
				/[`~!@#$%^&*()_\-+=<>?:"{}|,/;'\\[\]·~！@#￥%……&*（）——\-+={}|《》？：“”【】、；‘’，。、a-zA-ZeE]/g;
			break;
		case 'money':
			reg =
				/[`~!@#$%^&*()_\-+=<>?:"{}|,/;'\\[\]·~！@#￥%……&*（）——\-+={}|《》？：“”【】、；‘’，。、a-zA-ZeE]/g;
			break;
		case 'password':
			reg = /[`！@#￥%……&*（）——\-+={}|《》？：“”【】、；‘’，。、\u4e00-\u9fa5]/g;
			break;
		case 'money2':
			reg = /[a-zA-ZeE\u4e00-\u9fa5]/g;
			break;
		case 'money3':
			reg =
				/[`~!@#$%^&*()_\+=<>?:"{}|,/;'\\[\]·~！@#￥%……&*（）——\+={}|《》？：“”【】、；‘’，。、a-zA-ZeE]/g;
			break;
		case 'code':
			reg = /[0-9A-Za-z]/g;
			break;
    case 'cardId':
      reg = /[~!@#$%^&*()_\+=<>?:"{}|,/;'\\[\]·~！@#￥%……&*（）——\+={}|《》？：“”【】、；‘’，。、.\u4e00-\u9fa5]/g;
      break;
		default:
			break;
	}

	value = value.replace(reg, '').replace(/\s/g, '');
	if (value.length >= number) {
		this.$message({
			type: 'warning',
			message: `输入内容不能超过${number}个字符`
		});
	}
	if (type === 'money3') {
		return Number(value);
	}
	return value;
}

export const getMaxDay = (month = new Date().getMonth() + 1) => {
	month = Number(month);
	const maxMonty = [1, 3, 5, 7, 8, 10, 12];
	const minMonth = [4, 6, 9, 11];
	if (maxMonty.indexOf(month) !== -1) {
		return 31;
	} else if (minMonth.indexOf(month) !== -1) {
		return 30;
	} else {
		return 28;
	}
};
export const getnewMaxDay = (date) => {
  console.log(date)
  const data = new Date(date);
  const year = Number(data.getFullYear());
	const month = Number(data.getMonth() + 1);
	const maxMonty = [1, 3, 5, 7, 8, 10, 12];
	const minMonth = [4, 6, 9, 11];
	if (maxMonty.indexOf(month) !== -1) {
		return 31;
	} else if (minMonth.indexOf(month) !== -1) {
		return 30;
	} else if(year % 4 == 0 && year % 100 != 0 || year % 400 == 0) {
		return 29;
	}else{
    return 28;
  }
};
export const isIE = () => {
	// return !Vue.prototype.$isServer && !isNaN(Number(document.documentMode))
	return !isNaN(Number(document.documentMode));
};


/** 2022-01 =》 ['2022-01-01','2022-01-31'] */
export const getMonthDateArr = (yearMonth) => {
	return [
		timeFormat(null, yearMonth) + '-01',
		yearMonth + '-' + getnewMaxDay(yearMonth)
	];
};
export const getPrevMonth = () => {
  var dateObj = new Date();
  const Y = dateObj.getFullYear();
  const M = dateObj.getMonth() + 1;
  const addO = (num) => {
    let n = num === 0 ? 12: num;
    return n <= 9 ? '0' + n : n;
  };
  let date = M === 1 ? `${Y - 1}-${addO(M - 1)}` : `${Y}-${addO(M - 1)}`;
  return date;
}
export const getPrevMonthDateArr = () => {
  let yearMonth = getPrevMonth();
	return [
		timeFormat(null, yearMonth) + '-01',
		yearMonth + '-' + getMaxDay(yearMonth.split('-')[1])
	];
};


//数字转中文
export const toChinesNum = (num) => {
	let changeNum = ['零', '一', '二', '三', '四', '五', '六', '七', '八', '九'];
	let unit = ['', '十', '百', '千', '万'];
	num = parseInt(num);
	let getWan = (temp) => {
		let strArr = temp.toString().split('').reverse();
		let newNum = '';
		let newArr = [];
		strArr.forEach((item, index) => {
			newArr.unshift(item === '0' ? changeNum[item] : changeNum[item] + unit[index]);
		});
		let numArr = [];
		newArr.forEach((m, n) => {
			if (m !== '零') numArr.push(n);
		});
		if (newArr.length > 1) {
			newArr.forEach((m, n) => {
				if (newArr[newArr.length - 1] === '零') {
					if (n <= numArr[numArr.length - 1]) {
						newNum += m;
					}
				} else {
					newNum += m;
				}
			});
		} else {
			newNum = newArr[0];
		}
		return newNum;
	};
	let overWan = Math.floor(num / 10000);
	let noWan = num % 10000;
	if (noWan.toString().length < 4) {
		noWan = '0' + noWan;
	}
	return overWan ? getWan(overWan) + '万' + getWan(noWan) : getWan(num);
};
export const getPlaceholder = (n) => {
	return (1).toFixed(n).replace('.', '').slice(1);
};

// 下载地址
export function navDown(kid) {
	window.open(process.env.VUE_APP_BASE_API + config.downUrl(kid));
}

export const getLengthArr = (len, Str) => {
	return [...Array(len)].map((x) => Str);
};

/**
 * 数组过滤返回对应的值
 * list 数据源
 * dicCode 值与数据源中那个字段对应
 * dicName 返回数据源的那个字段
 */
export const nameFiltering = (value, list = [], dicCode, dicName,children='children') => {
	let result = '';
	if (!value || value === '') {
		result = '-';
	} else {

    traverseArr(list,dicCode,value,children);
		// list.map((item) => {
		// 	if (item[`${dicCode}`] === value) {
		// 		result = item[`${dicName}`];
		// 	}
		// });
		// result = timeFormat(new Date(value).getTime(), format);
	}

	return result;
};
export const traverseArr = (list,dicCode,value,children) => {
  var dicNames;
  let res ;
  try {
    list.forEach(e => {
      if(e[dicCode] === value){
        res = e;
        throw new Error('LoopInterrupt');
      }else {
        if(e[children]){
          traverseArr(e[children],dicCode,value,children)
        }
      }
    })
    return res;
  }catch(e) {
    dicNames = res;
  }

}

export function treeToArray(tree) {
	let res = []
	for (const item of tree) {
		const { children, ...i } = item
		if (children && children.length) {
			res = res.concat(treeToArray(children))
		}
		res.push(i)
	}
	return res
}
export const formatSelect = (
  list,
  value,
  selectValue,
  selectLabel,
  selectChildren = 'children'
) => {
  let selectLabels;
  let listData = treeToArray(list);
  for (let index = 0; index < listData.length; index++) {
    const e = listData[index];
    if(e[selectValue] ===value){
      selectLabels = e[selectLabel];
      break;
    }
  }
  return selectLabels;
};

export const getSelectLabel = (data = [], value) => {
  const dArr = data.filter((e) => e.value === value);
  return dArr[0] && dArr[0].label
};

export const getYearStartEnds = () => {

  var dateObj = new Date();
  const Y = dateObj.getFullYear();
  const M = dateObj.getMonth() + 1;
  const addO = (num) => {
    let n = num === 0 ? 12: num;
    return n <= 9 ? '0' + n : n;
  };

  return [`${Y}-01-01`, `${Y}-${addO(M)}-01`];
};


export const moneyTransfer = (money)  => {
  var cnNums = new Array("零", "壹", "贰", "叁", "肆", "伍", "陆", "柒", "捌", "玖"); //汉字的数字
  var cnIntRadice = new Array("", "拾", "佰", "仟"); //基本单位
  var cnIntUnits = new Array("", "万", "亿", "兆"); //对应整数部分扩展单位
  var cnDecUnits = new Array("角", "分", "毫", "厘"); //对应小数部分单位
  var cnInteger = "整"; //整数金额时后面跟的字符
  var cnIntLast = "元"; //整型完以后的单位
  var maxNum = 999999999999999.9999; //最大处理的数字
  var IntegerNum; //金额整数部分
  var DecimalNum; //金额小数部分
  var ChineseStr = ""; //输出的中文金额字符串
  var parts; //分离金额后用的数组，预定义
  var Symbol = ""; //正负值标记
  if (money == "") {
    return "";
  }

  money = parseFloat(money);
  if (money >= maxNum) {
    alert('超出最大处理数字');
    return "";
  }
  if (money == 0) {
    ChineseStr = cnNums[0] + cnIntLast + cnInteger;
    return ChineseStr;
  }
  if (money < 0) {
    money = -money;
    Symbol = "负 ";
  }
  money = money.toString(); //转换为字符串
  if (money.indexOf(".") == -1) {
    IntegerNum = money;
    DecimalNum = '';
  } else {
    parts = money.split(".");
    IntegerNum = parts[0];
    DecimalNum = parts[1].substr(0, 4);
  }
  if (parseInt(IntegerNum, 10) > 0) { //获取整型部分转换
    var zeroCount = 0;
    var IntLen = IntegerNum.length;
    for (var i = 0; i < IntLen; i++) {
      var n = IntegerNum.substr(i, 1);
      var p = IntLen - i - 1;
      var q = p / 4;
      var m = p % 4;
      if (n == "0") {
        zeroCount++;
      } else {
        if (zeroCount > 0) {
          ChineseStr += cnNums[0];
        }
        zeroCount = 0; //归零
        ChineseStr += cnNums[parseInt(n)] + cnIntRadice[m];
      }
      if (m == 0 && zeroCount < 4) {
        ChineseStr += cnIntUnits[q];
      }
    }
    ChineseStr += cnIntLast;
    //整型部分处理完毕
  }
  if (DecimalNum != '') { //小数部分
    var decLen = DecimalNum.length;
    for (var i = 0; i < decLen; i++) {
      var n = DecimalNum.substr(i, 1);
      if (n != '0') {
        ChineseStr += cnNums[Number(n)] + cnDecUnits[i];
      }
    }
  }
  if (ChineseStr == '') {
    ChineseStr += cnNums[0] + cnIntLast + cnInteger;
  } else if (DecimalNum == '') {
    ChineseStr += cnInteger;
  }
  ChineseStr = Symbol + ChineseStr;

  return ChineseStr;
}

export const downloadLodopUrl = '/nh-cloud/download/2c91ofsdfsdewr5401713922db5uij01';
